/****************************************************************************
**  MDHashTool - Message Digest (MD5, SHA-1, etc.) tool
**  Copyright (c) 2005  Charles Melhorn
**
**  This file is part of MDHashTool.
**
**  MDHashTool is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  MDHashTool is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
**  Or see the GNU web site at: http://www.gnu.org
**
****************************************************************************/ 

const gMDHTPrefConstants =
{
  PT_BOOL:         0,  // preference types
  PT_INT:          1,
  PT_STR:          2,
  PT_UNICHAR:      3,
  PT_UNICHARLOCAL: 4,
  PT_FILE:         5
}

var gMDHTPrefService = Components.classes["@mozilla.org/preferences-service;1"]
                            .getService(Components.interfaces.nsIPrefService);

const gMDHTUserPreferenceInfo = 
{
  default_hash_alg:   {defvalue: "MD5", prefname: "defaulthashalg", preftype: gMDHTPrefConstants.PT_STR},

  prefNode:           gMDHTPrefService.getBranch("extensions.mdht."),

  getPrefValue:       function(prefId_str)
  {
    return (getMDHTUserPreference(this[prefId_str].prefname,
                                this[prefId_str].defvalue,
                                this[prefId_str].preftype,
                                this.prefNode));
  },

  getPrefDefValue:    function(prefId_str)
  {
    return this[prefId_str].defvalue;
  },

  setPrefValue:       function(prefId_str, value)
  {
    setMDHTUserPreference(this[prefId_str].prefname,
                        value,
                        this[prefId_str].preftype,
                        this.prefNode);
  }

}


function getMDHTUserPreference(prefName, defValue, prefType, prefNode)
{
  var e, rv;

  switch(prefType)
   {
     case gMDHTPrefConstants.PT_BOOL:

       try {rv = prefNode.getBoolPref(prefName);}
        catch (e) { rv = defValue; }        

       break;

     case gMDHTPrefConstants.PT_INT:
       
       try {rv = prefNode.getIntPref(prefName);}
        catch (e) { rv = defValue; }        

       break;

     case gMDHTPrefConstants.PT_STR:

       try {rv = prefNode.getCharPref(prefName);}
        catch (e) { rv = defValue; }        

       break;

     case gMDHTPrefConstants.PT_UNICHAR:
     case gMDHTPrefConstants.PT_UNICHARLOCAL:
     case gMDHTPrefConstants.PT_FILE:

     default:
       alert("Preference type not implemented"); // DEBUG
   }

  return rv;
}


function setMDHTUserPreference(prefName, prefValue, prefType, prefNode)
{
  switch(prefType)
   {
     case gMDHTPrefConstants.PT_BOOL:
       prefNode.setBoolPref(prefName, prefValue);
       break;

     case gMDHTPrefConstants.PT_INT:
       prefNode.setIntPref(prefName, prefValue);
       break;

     case gMDHTPrefConstants.PT_STR:
       prefNode.setCharPref(prefName, prefValue);
       break;

     case gMDHTPrefConstants.PT_UNICHAR:
     case gMDHTPrefConstants.PT_UNICHARLOCAL:
     case gMDHTPrefConstants.PT_FILE:

     default:
       alert("Preference type not implemented"); // DEBUG
   }
}

